==> eiffelstudio-18.07.10.1981.tar: F_code/C4/cl193.c <==
/*
 * Code for class CLASS_TYPE_NAME_SYNTAX_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "cl193.h"
#include <ctype.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.default_create */
void F230_2893 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("default_create", 229, Current, 0, 0, 3044);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1054, 0x00).id, 1054, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1046_7836(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_valid_class_type_name */
EIF_BOOLEAN F230_2894 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("is_valid_class_type_name", 229, Current, 0, 1, 3045);
	RTGC;
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(2);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(3);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(4);
	F230_2895(Current);
	RTHOOK(5);
	Result = '\0';
	if (F230_2909(Current)) {
		Result = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 6L));
	}
	RTHOOK(6);
	RTLE;
	RTEE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_start */
void F230_2895 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("consume_start", 229, Current, 0, 0, 3046);
	RTGC;
	RTHOOK(1);
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) 'S';
	*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	RTHOOK(2);
	F230_2913(Current);
	RTHOOK(3);
	F230_2914(Current);
	RTHOOK(4);
	F230_2896(Current);
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type */
void F230_2896 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("consume_type", 229, Current, 0, 0, 3047);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 2L))) {
		RTHOOK(2);
		F230_2914(Current);
		RTHOOK(3);
		F230_2897(Current);
	} else {
		RTHOOK(4);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_generics */
void F230_2897 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("consume_generics", 229, Current, 0, 0, 3048);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 3L))) {
		RTHOOK(2);
		F230_2914(Current);
		RTHOOK(3);
		F230_2896(Current);
		RTHOOK(4);
		F230_2898(Current);
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type_list */
void F230_2898 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("consume_type_list", 229, Current, 0, 0, 3049);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 4L))) {
		RTHOOK(2);
		F230_2914(Current);
	} else {
		RTHOOK(3);
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 5L))) {
			RTHOOK(4);
			F230_2914(Current);
			RTHOOK(5);
			F230_2896(Current);
			RTHOOK(6);
			F230_2898(Current);
		} else {
			RTHOOK(7);
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
		}
	}
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.current_parsed_string */
EIF_REFERENCE F230_2907 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_end_of_input */
EIF_BOOLEAN F230_2909 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("is_end_of_input", 229, Current, 0, 0, 3060);
	RTGC;
	RTHOOK(1);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6684[Dtype(tr1)-1048])(RTCW(tr1));
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 > ti4_2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_eof */
EIF_BOOLEAN F230_2912 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_CHARACTER_32 tw1;
	EIF_CHARACTER_32 tw2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("is_eof", 229, Current, 0, 0, 3063);
	RTGC;
	RTHOOK(1);
	tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
	tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(tw1 == tw2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_character */
void F230_2913 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("consume_current_character", 229, Current, 0, 0, 3064);
	RTGC;
	RTHOOK(1);
	if (F230_2909(Current)) {
		RTHOOK(2);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	} else {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current);
		tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R6648[Dtype(tr1)-1049])(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_));
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
		RTHOOK(4);
		(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_))++;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_token */
void F230_2914 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("consume_current_token", 229, Current, 1, 0, 3043);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) != ((EIF_INTEGER_32) 7L))) {
		for (;;) {
			RTHOOK(2);
			tb1 = '\01';
			tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
			tb2 = EIF_TEST(isspace(tw1));
			if (!(EIF_BOOLEAN) !tb2) {
				tb1 = F230_2912(Current);
			}
			if (tb1) break;
			RTHOOK(3);
			F230_2913(Current);
		}
		RTHOOK(4);
		if ((EIF_BOOLEAN) !F230_2912(Current)) {
			RTHOOK(5);
			switch (*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_)) {
				case (EIF_CHARACTER_8) '[':
					RTHOOK(6);
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
					RTHOOK(7);
					F230_2913(Current);
					break;
				case (EIF_CHARACTER_8) ']':
					RTHOOK(8);
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 4L);
					RTHOOK(9);
					F230_2913(Current);
					break;
				case (EIF_CHARACTER_8) ',':
					RTHOOK(10);
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 5L);
					RTHOOK(11);
					F230_2913(Current);
					break;
				default:
					RTHOOK(12);
					tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
					tr1 = RTLNS(eif_new_type(1002, 0x00).id, 1002, _OBJSIZ_0_0_0_1_0_0_0_0_);
					*(EIF_CHARACTER_32 *)tr1 = tw1;
					tb2 = F1001_7690(RTCW(tr1));
					if (tb2) {
						RTHOOK(13);
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
						RTHOOK(14);
						tr1 = RTLNS(eif_new_type(1054, 0x00).id, 1054, _OBJSIZ_1_1_0_3_0_0_0_0_);
						F1053_8129(RTCW(tr1), ((EIF_INTEGER_32) 20L));
						loc1 = (EIF_REFERENCE) tr1;
						for (;;) {
							RTHOOK(15);
							tb2 = '\01';
							if (!F230_2912(Current)) {
								tb3 = '\01';
								tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
								tr1 = RTLNS(eif_new_type(1002, 0x00).id, 1002, _OBJSIZ_0_0_0_1_0_0_0_0_);
								*(EIF_CHARACTER_32 *)tr1 = tw1;
								tb4 = F1001_7698(RTCW(tr1));
								if (!tb4) {
									tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
									tb3 = (EIF_BOOLEAN)(*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) == tw1);
								}
								tb2 = (EIF_BOOLEAN) !tb3;
							}
							if (tb2) break;
							RTHOOK(16);
							F1055_8256(RTCW(loc1), *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_));
							RTHOOK(17);
							F230_2913(Current);
						}
						RTHOOK(18);
						tr1 = RTOUCR(574,F229_2881,(Current));
						tr2 = F1055_8276(RTCW(loc1));
						tb3 = F828_6681(RTCW(tr1), tr2);
						if (tb3) {
							RTHOOK(19);
							*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
						}
					} else {
						RTHOOK(20);
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
					}
					break;
			}
		} else {
			RTHOOK(21);
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 6L);
		}
	}
	RTHOOK(22);
	RTLE;
	RTEE;
}

void EIF_Minit193 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C4/cl193.c <==
/*
 * Code for class CLASS_TYPE_NAME_SYNTAX_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "cl193.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.default_create */
void F239_3006 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1078, 0x00).id, 1078, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1069_8283(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_valid_class_type_name */
EIF_BOOLEAN F239_3007 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	F239_3008(Current);
	Result = '\0';
	if (F239_3022(Current)) {
		Result = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 6L));
	}
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_start */
void F239_3008 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) 'S';
	*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	F239_3026(Current);
	F239_3027(Current);
	F239_3009(Current);
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type */
void F239_3009 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 2L))) {
		F239_3027(Current);
		F239_3010(Current);
	} else {
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_generics */
void F239_3010 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 3L))) {
		F239_3027(Current);
		F239_3009(Current);
		F239_3011(Current);
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type_list */
void F239_3011 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 4L))) {
		F239_3027(Current);
	} else {
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 5L))) {
			F239_3027(Current);
			F239_3009(Current);
			F239_3011(Current);
		} else {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
		}
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_end_of_input */
EIF_BOOLEAN F239_3022 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R7086[Dtype(RTCW(tr1))-1072])(tr1);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 > ti4_2);
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_eof */
EIF_BOOLEAN F239_3025 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_32 tw1;
	EIF_CHARACTER_32 tw2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
	tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(tw1 == tw2);
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_character */
void F239_3026 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if (F239_3022(Current)) {
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current);
		tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R7050[Dtype(RTCW(tr1))-1072])(tr1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_));
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
		(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_))++;
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_token */
void F239_3027 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLIU(3);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) != ((EIF_INTEGER_32) 7L))) {
		for (;;) {
			tb1 = '\01';
			tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
			tr1 = RTLNS(eif_new_type(1022, 0x00).id, 1022, _OBJSIZ_0_0_0_1_0_0_0_0_);
			*(EIF_CHARACTER_32 *)tr1 = tw1;
			tb2 = F1021_8119(RTCW(tr1));
			if (!(EIF_BOOLEAN) !tb2) {
				tb1 = F239_3025(Current);
			}
			if (tb1) break;
			F239_3026(Current);
		}
		if ((EIF_BOOLEAN) !F239_3025(Current)) {
			switch (*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_)) {
				case (EIF_CHARACTER_8) '[':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
					F239_3026(Current);
					break;
				case (EIF_CHARACTER_8) ']':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 4L);
					F239_3026(Current);
					break;
				case (EIF_CHARACTER_8) ',':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 5L);
					F239_3026(Current);
					break;
				default:
					tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
					tr1 = RTLNS(eif_new_type(1022, 0x00).id, 1022, _OBJSIZ_0_0_0_1_0_0_0_0_);
					*(EIF_CHARACTER_32 *)tr1 = tw1;
					tb2 = F1021_8113(RTCW(tr1));
					if (tb2) {
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
						loc1 = RTLNS(eif_new_type(1078, 0x00).id, 1078, _OBJSIZ_1_1_0_3_0_0_0_0_);
						F1077_8582(RTCW(loc1), ((EIF_INTEGER_32) 20L));
						for (;;) {
							tb2 = '\01';
							if (!F239_3025(Current)) {
								tb3 = '\01';
								tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
								tr1 = RTLNS(eif_new_type(1022, 0x00).id, 1022, _OBJSIZ_0_0_0_1_0_0_0_0_);
								*(EIF_CHARACTER_32 *)tr1 = tw1;
								tb4 = F1021_8121(RTCW(tr1));
								if (!tb4) {
									tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
									tb3 = (EIF_BOOLEAN)(*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) == tw1);
								}
								tb2 = (EIF_BOOLEAN) !tb3;
							}
							if (tb2) break;
							F1079_8710(RTCW(loc1), *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_));
							F239_3026(Current);
						}
						tr1 = RTOSCF(2994,F238_2994, (Current));
						tb3 = F824_6649(RTCW(tr1), loc1);
						if (tb3) {
							*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
						}
					} else {
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
					}
					break;
			}
		} else {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 6L);
		}
	}
	RTLE;
}

void EIF_Minit193 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
